Stock Lot Shelf Life Expiration Date
####################################

The stock_lot_sled module adds two fields on lot of products:

    - Shelf Live Expiration Date
    - Expiration Date

And it defines on the product the default time for those fields.

When a lot is expired, it is no more used to compute the forecast quantity of
the stock.
